@@ -1,18 +1,25 @@
-from firstimpression.constants import APIS
-from firstimpression.constants import TEMP_FOLDER
-from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
-from firstimpression.constants import NAMELEVEL
-from firstimpression.file import update_directories_api
-from firstimpression.file import check_too_old
-from firstimpression.file import write_root_to_xml_files
-from firstimpression.scala import log 
-from firstimpression.scala import variables
-from firstimpression.api.request import request
-import xml.etree.ElementTree as ET
 import os
 import glob
+from firstimpression import file
 import lxml.html
+import xml.etree.ElementTree as ET
 
+from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER
+from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files
+from firstimpression.scala import variables, Log
+from firstimpression.api.request import request
+
+
+##################################################################################################
+# LOGGING
+##################################################################################################
+
+script = 'Eindhoven Airport'
+
+info = Log('INFO', script)
+debug = Log('DEBUG', script)
+warn = Log('WARN', script)
+error = Log('ERROR', script)
 
 ##################################################################################################
 # CONSTANTS
@@ -35,6 +42,9 @@ TABLE_FLIGHTS_XPATH = '//div[@id="skyguide"]/div/table'
 
 def run_api():
 
+    debug.log('folder name: {}'.format(NAME))
+    debug.log('temp path: {} - local path: {}'.format(XML_TEMP_PATH, XML_LOCAL_PATH))
+
     update_directories_api(NAME)
 
     if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
@@ -64,6 +74,7 @@ def run_api():
                 elif column_number == 4:
                     ET.SubElement(item, "status").text = column_text[0]
                     if not "Vertrokken" in column_text[0]:
+                        debug.log('flight {} already left'.format(item.findtext('flight_number')))
                         store = True
                 elif column_number == 5:
                     pass
@@ -75,17 +86,27 @@ def run_api():
         
         write_root_to_xml_files(root, XML_TEMP_PATH, NAME)
     else:
-        log(NAMELEVEL['INFO'], 'File not old enough to update')
+        debug.log('File not old enough to update')
 
 def check_api():
     svars = variables()
 
-    file_path = glob.glob(XML_LOCAL_PATH)[0]
+    file_path = glob.glob(XML_LOCAL_PATH)
 
-    if check_too_old(file_path, MAX_FILE_AGE):
-        svars['skipscript'] = True
+    if len(file_path) > 0:
+        file_path = file_path[0]
+        debug.log('glob filepath: {}'.format(file_path))
+
+        if check_too_old(file_path, MAX_FILE_AGE):
+            svars['skipscript'] = True
+            info.log('file too old')
+        else:
+            svars['skipscript'] = False
     else:
-        svars['skipscript'] = False
+        warn.log('File does not exists')
+        svars['skipscript'] = True
+        
+    
 
 
 
