@@ -1,21 +1,25 @@
-from firstimpression.constants import APIS
-from firstimpression.constants import TEMP_FOLDER
-from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
-from firstimpression.constants import ENGLISH_INDEX
-from firstimpression.constants import DUTCH_INDEX
-from firstimpression.file import update_directories_api
-from firstimpression.file import check_too_old
-from firstimpression.file import write_root_to_xml_files
-from firstimpression.file import download_install_media
-from firstimpression.file import list_files_dir
-from firstimpression.time import change_language
-from firstimpression.time import parse_string_to_string
-from firstimpression.text import remove_emoji
-from firstimpression.scala import variables
-from firstimpression.api.request import request_json
 import xml.etree.ElementTree as ET
 import os
 import glob
+from firstimpression import file
+
+from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, ENGLISH_INDEX, DUTCH_INDEX
+from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files, download_install_media, list_files_dir
+from firstimpression.time import change_language, parse_string_to_string
+from firstimpression.text import remove_emoji
+from firstimpression.scala import variables, Log
+from firstimpression.api.request import request_json
+
+##################################################################################################
+# LOGGING
+##################################################################################################
+
+script = 'Instagram'
+
+info = Log('INFO', script)
+debug = Log('DEBUG', script)
+warn = Log('WARN', script)
+error = Log('ERROR', script)
 
 ##################################################################################################
 # CONSTANTS
@@ -37,14 +41,21 @@ XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, 'instagram.xml')
 ##################################################################################################
 
 def run_api(api_key, max_minutes, max_characters, max_items, language):
+
+    debug.log('folder name: {}'.format(NAME))
+    debug.log('file path temp: {} - local: {}'.format(XML_TEMP_PATH, LOCAL_PATH))
     
     max_file_age = 60 * max_minutes
 
+    debug.log('max_file_age: {}'.format(max_file_age))
+
     if language == 'NL':
+        info.log('change language to dutch')
         change_language(DUTCH_INDEX)
         datetime_format_new = '%d %B %Y'
         language_index = DUTCH_INDEX
     else:
+        info.log('change language to english')
         change_language(ENGLISH_INDEX)
         datetime_format_new = '%B %d %Y'
         language_index = ENGLISH_INDEX
@@ -72,6 +83,7 @@ def run_api(api_key, max_minutes, max_characters, max_items, language):
 
             thumbnail_url = get_media(post)
             if thumbnail_url is None:
+                debug.log('image not found so using placeholder')
                 media_link = 'Content:\\placeholders\\img.png'
             else:
                 media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
@@ -84,21 +96,34 @@ def run_api(api_key, max_minutes, max_characters, max_items, language):
                 ET.SubElement(item, "media_type").text = "image"
 
         write_root_to_xml_files(root, XML_TEMP_PATH, NAME)        
-
+    else:
+        debug.log('File not old enough to update')
 def check_api(max_minutes):
     svars = variables()
 
     max_file_age = 60 * max_minutes
 
+    debug.log('max_file_age: {}'.format(max_file_age))
+
     file_name = 'instagram*.xml'.format()
     file_path = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, file_name)
 
-    file_path = glob.glob(file_path)[0]
+    debug.log('local path: {}'.format(file_path))
 
-    if check_too_old(file_path, max_file_age):
-        svars['skipscript'] = True
+    file_path = glob.glob(file_path)
+
+    if len(file_path) > 0:
+        file_path = file_path[0]
+        debug.log('glob filepath: {}'.format(file_path))
+
+        if check_too_old(file_path, max_file_age):
+            svars['skipscript'] = True
+            info.log('file too old')
+        else:
+            svars['skipscript'] = False
     else:
-        svars['skipscript'] = False
+        warn.log('File does not exists')
+        svars['skipscript'] = True
 
 
 ##################################################################################################
