@@ -1,24 +1,24 @@
-from firstimpression.constants import APIS
-from firstimpression.constants import TEMP_FOLDER
-from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
-from firstimpression.constants import IMG_EXTENSIONS
-from firstimpression.constants import VIDEO_EXTENSIONS
-from firstimpression.constants import DUTCH_INDEX
-from firstimpression.file import create_directories
-from firstimpression.file import write_root_to_xml_files
-from firstimpression.file import update_directories_api
-from firstimpression.file import check_too_old
-from firstimpression.file import list_files
-from firstimpression.file import download_install_media
-from firstimpression.time import change_language
-from firstimpression.time import parse_date_to_string
-from firstimpression.time import parse_timestamp_to_date
-from firstimpression.scala import variables
-from firstimpression.api.request import request_json
 import xml.etree.ElementTree as ET
 import glob
 import os
 
+from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, IMG_EXTENSIONS, VIDEO_EXTENSIONS, DUTCH_INDEX
+from firstimpression.file import create_directories, write_root_to_xml_files, update_directories_api, check_too_old, list_files, download_install_media
+from firstimpression.time import change_language, parse_date_to_string, parse_timestamp_to_date
+from firstimpression.scala import variables, Log
+from firstimpression.api.request import request_json
+
+##################################################################################################
+# LOGGING
+##################################################################################################
+
+script = 'Weather'
+
+info = Log('INFO', script)
+debug = Log('DEBUG', script)
+warn = Log('WARN', script)
+error = Log('ERROR', script)
+
 ##################################################################################################
 # CONSTANTS
 ##################################################################################################
@@ -104,7 +104,7 @@ TAGS = {
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(api_key, icon_set, location, units, lang='nl'):
+def run_api(api_key, icon_set, location='', units='metric', lang='nl', coordinates=None):
     params = {
         'q': location,
         'appid': api_key, 
@@ -112,6 +112,11 @@ def run_api(api_key, icon_set, location, units, lang='nl'):
         'lang': lang
     }
 
+    if not coordinates is None:
+        del params['q']
+        params['lon'] = coordinates['longitude']
+        params['lat'] = coordinates['latitude']
+
     url_icons = 'http://37.97.211.104/narrowcasting/weather/weather_{}'.format(icon_set)
 
     extensions = IMG_EXTENSIONS + VIDEO_EXTENSIONS
@@ -119,6 +124,10 @@ def run_api(api_key, icon_set, location, units, lang='nl'):
     temp_folder_icons = os.path.join(TEMP_FOLDER, NAME, 'icons', icon_set)
     local_folder_icons = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'icons', icon_set)
 
+    debug.log('folder name: {}'.format(NAME))
+    debug.log('params: {} - url icons: {} - extensions: {}'.format(params, url_icons, extensions))
+    debug.log('folder icons temp: {} - local: {}'.format(temp_folder_icons, local_folder_icons))
+
     create_directories([temp_folder_icons, local_folder_icons])
     update_directories_api(NAME)
     change_language(DUTCH_INDEX)
@@ -169,17 +178,27 @@ def run_api(api_key, icon_set, location, units, lang='nl'):
             ET.SubElement(item, "icon").text = get_icon(day, icon_set)
 
         write_root_to_xml_files(root, XML_TEMP_PATH, NAME)
+    else:
+        debug.log('File not old enough to update')
 
 def check_api():
 
     svars = variables()
 
-    file_path = glob.glob(XML_LOCAL_PATH)[0]
+    file_path = glob.glob(XML_LOCAL_PATH)
 
-    if check_too_old(file_path, MAX_FILE_AGE):
-        svars['skipscript'] = True
+    if len(file_path) > 0:
+        file_path = file_path[0]
+        debug.log('glob filepath: {}'.format(file_path))
+
+        if check_too_old(file_path, MAX_FILE_AGE):
+            svars['skipscript'] = True
+            info.log('file too old')
+        else:
+            svars['skipscript'] = False
     else:
-        svars['skipscript'] = False
+        warn.log('File does not exists')
+        svars['skipscript'] = True
 
 ##################################################################################################
 # MEDIA FUNCTIONS
@@ -189,6 +208,7 @@ def download_icons(url_icons, extensions, temp_folder_icons, icon_set):
     icons = list_files(url_icons, extensions)
 
     for icon in icons:
+        debug.log('icon: {}'.format(icon))
         if check_too_old(os.path.join(temp_folder_icons, icon), MAX_FILE_AGE_IMAGES):
             download_install_media(url_icons + '/{}'.format(icon), TEMP_FOLDER, '{}\\icons\\{}'.format(NAME, icon_set))
 
