@@ -44,10 +44,11 @@ def download_media(media_link, subdirectory, temp_folder, filename=None):
         media_filename = filename
     media_path = os.path.join(temp_folder, subdirectory, media_filename)
 
-    if not os.path.exists(media_path):
-        response = requests.get(media_link, stream=True)
-        with open(media_path, 'wb') as writefile:
-            shutil.copyfileobj(response.raw, writefile)
+    response = requests.get(media_link, stream=True)
+
+    with open(media_path, 'wb') as writefile:
+        shutil.copyfileobj(response.raw, writefile)
+
     return media_path
 
 
@@ -90,6 +91,9 @@ def list_files(url, extensions):
     select_elements = [elem for elem in all_elements if '.' + elem.split('.')[-1] in extensions]
     return select_elements
 
+def list_files_dir(path):
+    return [file for file in os.listdir(path) if os.path.isfile(os.path.join(path, file))]
+
 def update_directories_api(api_name, max_days=1):
     temp_folder = os.path.join(TEMP_FOLDER, api_name)
     local_folder = os.path.join(LOCAL_INTEGRATED_FOLDER, api_name)
