@@ -469,10 +469,16 @@ def sleep(secs):
             raise
 
 class Log:
-    def __init__(self, name):
+    def __init__(self, name, script):
         self.name = name
         self.level = NAMELEVEL[name]
+        self.script = script
+        try:
+            self.debug = variables()['Player.debug_python']
+        except KeyError:
+            self.debug = False
     
     def log(self, msg):
-        log(self.level, msg)
+        if (self.level == NAMELEVEL['DEBUG'] and self.debug) or not self.level == NAMELEVEL['DEBUG']:
+            log(self.level, '{}: {}'.format(self.script, msg))
 
